@@ -36,9 +36,13 @@ class Insider:
     def get_mapping(self, port):
         return self.port_mapper.get(port)
 
+    # TODO: Remove after owncloud-ctl migration to service_info
     def service_urls(self, name):
         return self.dns.service_urls(name)
 
+    def service_info(self, name):
+        return self.dns.service_info(name)
+
     def acquire_domain(self, email, password, user_domain):
         return self.dns.acquire(email, password, user_domain)
 
@@ -58,6 +62,7 @@ class Insider:
     def set_redirect_info(self, domain, api_url):
         return self.insider_config.update(domain, api_url)
 
+
 def get_insider(bin_path, config_path, logs_path):
 
     script_path = os.path.join(bin_path, 'insidercli')
